import logging

from pyathena import connect


def initialization(
    region,
    query_output_s3_bucket,
    # db_s3_bucket="s3://cdca-prod-us-east-1-intermediate-data/mature_org_db/",
    db_s3_bucket="s3://gdev4-policysuggestion-infra-intermediate-data-bucket/mature_org_db/",
):
    try:
        logging.debug("Initialize mature_org_db database and table")
        cursor = connect(
            s3_staging_dir=query_output_s3_bucket, region_name=region,
        ).cursor()
        create_database_command = f"""
        CREATE DATABASE `mature_org_db` LOCATION '{db_s3_bucket}'
        """
        logging.debug(create_database_command)
        cursor.execute(create_database_command)

        create_org_list_table_command = f"""CREATE EXTERNAL TABLE IF NOT EXISTS mature_org_db.mature_org_list (
            orgid INT,
            device_count BIGINT,
            reputation_whitelist_rule_count INT,
            reputation_blacklist_rule_count INT,
            org_existence_in_days INT,
            user_added_rule_count INT,
            user_added_blocking_rule_count INT,
            user_added_permission_rule_count INT,
            num_of_policy_with_more_than_median_blocking_permission_rule INT,
            total_policy_num BIGINT,
            blocking_rule_count BIGINT,
            permission_rule_count BIGINT,
            all_event_count BIGINT,
            blocking_event_count BIGINT,
            blocking_event_ratio DOUBLE
            )
        STORED AS PARQUET
        LOCATION '{db_s3_bucket}mature_org_list/'
        tblproperties ("parquet.compress"="GZIP")"""
        logging.debug(create_org_list_table_command)
        cursor.execute(create_org_list_table_command)

        create_mature_org_score_command = f"""CREATE EXTERNAL TABLE IF NOT EXISTS mature_org_db.mature_org_score (
            orgid INT,
            device_count BIGINT,
            reputation_whitelist_rule_count INT,
            reputation_blacklist_rule_count INT,
            org_existence_in_days INT,
            user_added_rule_count INT,
            user_added_blocking_rule_count INT,
            user_added_permission_rule_count INT,
            num_of_policy_with_more_than_median_blocking_permission_rule INT,
            total_policy_num BIGINT,
            blocking_rule_count BIGINT,
            permission_rule_count BIGINT,
            all_event_count BIGINT,
            blocking_event_count BIGINT,
            blocking_event_ratio DOUBLE,
            org_maturity_score1 DOUBLE,
            org_maturity_score2 DOUBLE
            )
        STORED AS PARQUET
        LOCATION '{db_s3_bucket}mature_org_score/'
        tblproperties ("parquet.compress"="GZIP")"""
        logging.debug(create_mature_org_score_command)
        cursor.execute(create_mature_org_score_command)
    except Exception as e:
        logging.error(
            "Error in initializing mature_org_db db and table. Error details: %s",
            str(e),
        )
